from ativ_pacotes import armazenamento as ar


def interacao():
    nome = str(input('Digite o nome: \n'))
    cpf = str(input('Digite o CPF: \n'))
    endereco = str(input('Digite o endereco: \n'))

    ar.armazenamento(nome, cpf, endereco)


interacao()



def consulta():
    busca = str(input('Qual o cpf para busca? \n'))

    f = open(r'/atividade/dados_usuario.txt', 'r')
    dados = f.readlines()
    substr = ""
    count = 0
    for i in dados:
        if busca in i:
            for j in i:
                if j == ",":
                    count += 1

                if count != 1:
                    substr += j

            break

    print(substr)


consulta()



from setuptools import setup

with open("README.md", "r") as arq:
    readme = arq.read()

setup(name='ativ_pacotes',
      version='0.0.1',
      license='MIT License',
      author='Arthur Queiroz',
      long_description=readme,
      long_description_content_type="text/markdown",
      author_email='arthur21070032@aluno.cesupa.br',
      keywords='ativ pacotes',
      description=u'Repositório para atividade de sala, contendo módulos consulta; armazenamento; interacao',
      packages=['ativ_pacotes'],)
